==> text_to_sidc-0.0.11.tar.gz: text_to_sidc-0.0.11/tests/test_unit_designator.py <==
import pytest
from text_to_sidc.austrian import UnitDesignator

@pytest.mark.parametrize("input_text, expected_sidc", [
    # ОВТ
    ("08.08.21 1 од. ОіВТ невизначеного типу (Космічний знімок)", "10061500001200000000"),
    # C2, КШМ
    ("02.08.23 неідентифікований КП ров, на північний захід від Червонопопівка (Взаємодія)", "10061000001100000000"), 
    ("Командно-спостережний пункт (КСП)", "10061000001100000000"),
    ("КШМ", "10061500001201020000"),
    # ППО Бук
    ("18.08.23 1 ЗРК 9К37 “Бук” (Космічний знімок)", "10061500331111040000"), 
    ("09.09.23 1 од. ПУ Бук-М2 біля н.п Нововасилівка (Взаємодія)", "10061500331111040000"),
    ("БУК М3", "10061500331111040000"),
    ("БУК", "10061500331111040000"),
    ("9А317", "10061500331111040000"),
    ("BUK M3", "10061500331111040000"),
    ("BUK M2", "10061500331111040000"),
    # Additional test cases
         # ППО С-300В
    ("20.08.23 Російський С-300ВМ «Антей-2500» (Взаємодія)", "10061500331111070000"),
    ("РЛС 9С15", "10061500332203000000"),
    # РЛС
    ("21.08.23 РЛС 91N6 (Взаємодія)", "10061500322203000000"),
    ("РЛС 76Н6", "10061500322203000000"),
    ("ЗРК БУК М3 СОЦ 9С18 КУПОЛ", "10061500332203000000"),
    ("21.08.23 РЛС 91N6 (Взаємодія)", "10061500322203000000"),
    ("04.09.23 Ніобій-СВ", "10061500322203000000"),
    ("РЛС 1Л122-1Е «Гармонь»", "10061500002203000000"),
    ("РЛС ППО 1Л122-1Е Гармонь", "10061500002203000000"),
    # Тестую регулярку
    # ("Я ищу в РЛСAвске ", None),
    # ІФО
    ("Траншея", "10062500002812000000"),
    ("Окоп", "10062500002812000000"),
    ("Виявлено ФОМ (космічний знімок)", "10062500002812000000"),
    # Пеленги радіостанцій космос
    ("VSAT", "10061000001110040000"),
    ("P-438", "10061000001110040000"),
    ("Р-441", "10061000001110040000"),
    ("Пеленг станції тропосферного зв'язку Р-423", "10061000001110040000"),
    ("MULTIPLE GROUND SATELLITES", "10061000001110040000"),
    # Пеленги радіостанцій
    ("Р-440", "10061500002001000000"),
    # Signal - Radio
    ("05.09.2023 Пеленг R-444 5386677 7424920", "10061000001110010000"),
    ("Р-444", "10061000001110010000"),
    ("Р-187", "10061000001110010000"),
    ("01.0923 Пеленг радіостанції Азарт R-187 61 Засічок  /10 днів, 47.4931, 35.6743", "10061000001110010000"),
    ("P-187", "10061000001110010000"),
    ("ПЕЛЕНГ РАДІОСТАНЦІЇ R-168", "10061000001110010000"),
    ("Р-168", "10061000001110010000"),
    ("Р-392", "10061000001110010000"),
    ("DMR", "10061000001110010000"),
    ("Пеленг УКХ зв'язку", "10061000001110010000"),
    ("P-392", "10061000001110010000"),
    ("АМ зв'язку", "10061000001110010000"),
    # Signal - Radio Relay
    ("Пеленг радіорелейної станції Р-419", "10061000001110020000"),
    ("Пеленг радіорелейної станції Р-415", "10061000001110020000"),
    ("Р-409", "10061000001110020000"),
    ("реле зв’язку св зс рф", "10061000001110020000"),
    # Signal
    ("10.09.23 АМ зв’язку (Взаємодія)", "10061000001110000000"),
    ("Пеленг невстановленого обладнання", "10061000001110000000"),
    ("AR-2", "10061000001110000000"),
    ("COMMS STATION", "10061000001110000000"),
    #
    ("22.08.23 Вогневе ураження", "10064000001106000000"),
    ("26.08.23 МТ-12 Рапіра", "10061500351106010000"),
    ("31.08.23 1 БАТ-2, 5 вантажних військових автомобілів (Космічний знімок)", "10061500001311000000"),
    ("01.09.23 'Стріла-2М' (9К32)", "10061500331111010000"),
    ("09.09.23 «Стріла-3» (9К34)", "10061500331111010000"),
    # ЗРК ТОР
    ("02.09.23 ЗРК ТОР рф (Взаємодія)", "10061500331111050000"),
    ("ТОР М2", "10061500331111050000"),
    ("TOP М1", "10061500331111050000"),
    ("ТОР М1", "10061500331111050000"),
    ("SAM TOR M2", "10061500331111050000"),
    ("SAM TOR M1/M2", "10061500331111050000"),
    ("SA-15", "10061500331111050000"),
    # Панцир
    ("31.08.23 ЗРК ПАНЦИРЬ-С2 (Взаємодія)", "10061500321111040000"),
    ("01.09.23 ЗРГК ПАНЦИР рф (Взаємодія)", "10061500321111040000"),
    ("02.09.23 ЗРГК ПАНЦИР-С2 (Взаємодія)", "10061500321111040000"),
    ("ЗРК ППО ПАНЦИР С1", "10061500321111040000"),
    ("ЗРК ППО ПАНЦИР С2", "10061500321111040000"),
    ("ЗРК ППО ОСА", "10061500321111050000"),
    ("ОСА", "10061500321111050000"),
    ("ЗРК Панцир-С2", "10061500321111040000"),
    # РЕБ
    ("04.09.23 Комплекс придушення сигналів навігаційних систем", "10061000001505040000"),
    ("04.09.23 Борисоглебськ-2", "10061000001505040000"),
    ("10.09- Пеленг P-934БМВ 50.2731 38.0172", "10061000001505040000"),
    ("04.09.23 96Л6", "10061500322203000000"),
    ("Р-934", "10061000001505040000"),
    ("Створення перешкод", "10061000001505040000"),
    ("EW", "10061000001505040000"),
    # мінування
    ("05.09.23 Район мінування", "10062500002707010000"),
    ("Міни ТМ-62", "10061500002103000000"),
    # птрк
    ("04.09.23 «Метис-М» (9К115-2)", "10061500001112030000"),
    ("17.09.23 позиція ПТРК 72 омсбр", "10061500001112000000"),
    ("Пускова установка протитанкової ракети", "10061500001117000000"),
    # паливо
    ("Топливозаправники 4 од.", "10061500321409000000"),
    ("Транспорт ПММ", "10061500321409000000"),
    ("30 ОС, 5 ВАТ, 7 бензовозів", "10061500321409000000"),
    # артилерія
    ("ствольна артилерія", "10061500351109000000"),
    ("Артилерія", "10061500351109000000"),
    ("Артилерійські установки", "10061500351109000000"),
    ("Орудие", "10061500351107000000"),
    ("ARTILLERY", "10061500351109000000"),
    # ОТРК
    ("Іскандер", "10061500321113000000"),
    # Піхота
    ("Піхота", "10061000001211000000"),
    ("INFANTRY", "10061000001211000000"),
    # міномет
    ("Міномет 120 мм (буксирований)", "10061500351114030000"),
    ("Артилерія на вогневих позиціях: ймовірно 1 міномет 2С4", "10061510331114030000"),
    ("MORTAR", "10061500001114000000"),
    # САУ
    (" Гвоздика", "10061500331109010000"),
    # Проживання
    ("Проживання ОС", "10062000001208000000"),
    # авіація
    ("Су-34 в польоті на південний захід", "10060100001101050000"),
    ("Ан-72", "10060100001101070000"),
    ("Ан-26", "10060100001101070000"),
    # Відео
    ("Відео (бойова камера)", "10061000001112000000"),
    # гранатомет
    ("Гранатомет", "10061500001103000000"),
    # ремонт і обслуговування
    ("Ремонтна база", "10062000001213060000"),
    ("База ремонту / відновлення", "10062000001213060000"),
    # медичка
    ("Стабілізаційний медичний пункт", "10062000001207020000"),
    # навчальний табір
    ("Навчальний табір", "10062000001119020000"),
    ("Навчальний полігон ров", "10062000001119020000"),
    # автомобілі / ЛАТ
    ("Автомобіль", "10061500001601000000"),
    # кулемет
    ("Кулемет", "10061500001102000000"),
    # вогневі позиції
    ("арт. позиція", "10062500002501000000"),
    ("вогневі позиції", "10062500002501000000"),
    # залізниця
    ("Залізнична станція РОДАКОВО", "10062000001213070000"),
    ("Залізничні станції Дебальцеве та Дебальцеве-Сортувальна", "10062000001213070000"),
    ("Локомотивне депо Дебальцеве", "10062000001213070000"),
    # місце перезаряджання
    ("Місце перезарядження  артилерії", "10062500003202000000"),
    # підрозділ
    ("тактичний підрозділ св зс рф", "10061000001200000000"),
    # евак
    ("Група евакуації", "10062500003211000000"),
    # КББ
    ("РЛК ЯСТРЕБ АВ", "10061500322203000000"),
    # СП
    ("Створення: 2024-01-10 13:52:40 | pep Оновлення: 2024-01-10 13:52:36 | pep Lat, Lng: 48.196246, 37.678888 DMS: N48°11'46.49', E37°40'44.00' СК-42: X: 5341194, Y: 7401900 MGRS: 37UDP0182638956 UTM: Z: 37U, E: 401826, N: 5338956 Тип: Спостережний пункт (СП) - Аванпост передового спостерігача - Точка/аванпост спостереження - Точки маневрування - Польові укріплення та умовні точки Ворожість: Ворожий Висота над рівнем моря, м: 204 UUID: 1f3d3d9e-24d8-4745-9932-694c241dc686", "10062500001601000000"),
    # точки
    ("Пункт загального постачання", "10062500003217000000"),
    ("TROOP SUSTAINMENT/MILITARY TRUCKS", "10062500003217000000"),
    ("TROOP SUSTAINMENT / CARGO", "10062500003217000000"),
    ("WEAPONS / EQUIPTMENT SHIPMENT", "10062500003217000000"),
    # склади
    ("склади боєприпасів", "10062000001103000000"),
    ("AMMUNITION CACHE", "10062000001103000000"),
    # БПЛА
    ("GCS", "10061000111219000021"),
    # інфраструктура
    ("Міст автомобільний, р. Красна, північ Сватове. з квітня 2023", "10062000001107010000"),
    ("BRIDGE CONSTRUCTION", "10062000001107010000"),
    ("FLOATING BRIDGE", "10061500001304000000"),
    ("Електропідстанція Михайлівська-400 ПС 400/330/220/110 кВ. від ЛБЗ 30 км", "10062000001205010000"),
    ("Електрична підстанція", "10062000001205010000"),
    ("WATER SUPPLY INFRASTRUCTURE", "10062000001214000000"),
    ("PETROL STATION", "10062000001205040000"),
    ("ENERGY FACILITY", "10062000001205000000"),
    # госпіталь/лікарня
    ("3RD MSD MEDICAL FACILITY", "10062000001207020000"),
    # вантажівка
    ("MILITARY CARGO VEHICLES", "10061500001408000000"),
    # антена
    ("BROADCAST ANTENNA", "10061500002001000000"),
    # міни
    ("Конец мон50 9шт, пмн4-20 шт, пмн2-70 шт", "10061500002102000000"),

    # c2
    ("c2 ", "10061000001100000000"),
    (" c2 ", "10061000001100000000"),
    ("c211", "10012500001313000000"),
    ("c2", "10061000001100000000"),
    ("c2", "10061000001100000000"),
    ("4с25-4g4g", "10012500001313000000"),
    ("4с2-4g4g", "10012500001313000000"),

    # КСП
    ("СПОСТЕРЕЖНИЙ ПУНКТ", "10062500001601000000"),
    ("КОМАНДНО-СПОСТЕРЕЖНИЙ ПУНКТ", "10061000001100000000"),

    # Підрозділи
    ("1008 ТрВ", "10061000001211000000"),
    ("7 орб 47 тд", "10061000161205010000"),
    ("1472 мсп 68 ак\39 омсбр (?)","10061000171211020000"),
    ("2614 сб МР","10061000151211040000"),
    ("БАРС-8","10061000001211000000"),
    # ("113 сп\116 осп  МР 1 АК","10062500001601000000"), видає таке, бо смика механ роту'10061000151211040000 МСР|МР'
    ("242 мсп 20 мсд 8 зва","10061000171211020000"),
    ("104 дшп 76 дшд","10061000171201000000"),
    ("22 обрспп","10061000001217000000"),
    ("4 осб ТрО","10061000161211000000"),
    ("1857 мсб ТрВ","10061000161211040000"),
    # ('119 сп МР\87 осп ""Пятнашка"" (?) 1 АК',"10062500001601000000"), смикає СП до підрозд
    ('7 ДРШБр ""Святой Георгій"""',"10061000001211000100"),
    ("272 мсп 47 тд 1 та","10061000171211020000"),
    ("1660 омсб 20 зва","10061000161211040000"),
    ("337 дшп 104 дшд ПДВ","10061000141201000000"),
    ("60 омсбр 5 зва","10061000181211040000"),
    ("3 мсб 347 мсп 47 тд 1 ТА","10061000161211040000"),
    ("БАРС-19","10061000001211000000"),
    ("ксб Єгорлик","10061000001211000000"),
    ("нв Ахмат","10061000001211001400"),
    ("БАРС-2 47 тд 1 та","10061000001211000000"),
    ("1618 омсб ТрВ","10061000161211040000"),
    ("БАРС-20","10061000001211000000"),
    ("79 орб 2 ак","10061000161213000000"),
    ("136 орб 2 мсд 1 ТА","10061000161205010000"),
    ("оз СпП 2 обрсппн","10061000001217000000"),
    ("1009 мсп (без 1 і 3 мсб) 25 омсбр 6 зва","10061000161211040000"),
    ("шр 5 мсб (з тр) 1 мсп 2 мсд","10061000161211040000"),
    ("26 сб 36 омсбр 29 зва","10061000161211000000"),
    ("85 омсбр 2 ак 8 зва","10061000181211040000"),
    ("1 дршбр “Волкі”","10061000001211000100"),
    ("11 отбр 25 зва","10061000001211000000"),
    ("підрозділи 388-ї бригади морського спецназу","10061000001217000000"),
    ("794 оз СпП 14 обрсппн","10061000001217000000"),
    ("2 обСпП ОБТФ","10061000001217000000"),
    ("1440 мсп ТрВ","10061000171211020000"),
    ("907 орб 27 мсд 2 зва","10061000161205010000"),
    ("137 пдп 106 пдд","10061000171201000000"),
    ("297 осб 2 ак","10061000161211000000"),
    ("382 обмп 810 обрмп","10061000001203000000"),
    ("12 мсб 6 оп РХБз 6 зва","10061000161211040000"),
    ("102 мсп 150 мсд","10061000171211020000"),
    ("1441 мсп ТрВ 30 омсбр 2 зва","10061000171211020000"),
    ("143 мсп 127 мсд 5 зва","10061000171211020000"),
    ("9 омсп9 омсбр 1 АК","10061000171211020000"),
    ("1436 мсп ТрВ 114 омсбр 1 ак 8 зва","10061000171211020000"),
    ("1 мсб 1009 мсп 25 омсбр 6 зва","10061000161211040000"),
    ("17 мсб з тр 488 мсп 144 мсд 20 зва","10061000161211040000"),
    ("1152 мсп ТрВ 47 мсд 18 зва","10061000171211020000"),
    ("102 ообпдс","10061000001211000000"),
    ("15 зсб 252 мсп 3 мсд 20 зва","10061000171211020000")

])

def test_unit_designator(input_text: str, expected_sidc: str) -> None:
    sidc = UnitDesignator.calculate_icon(input_text.upper())
    assert sidc == expected_sidc, f"Expected SIDC: {expected_sidc}, but got: {sidc} with input: {input_text}"

==> text_to_sidc-0.0.13.tar.gz: text_to_sidc-0.0.13/tests/test_unit_designator.py <==
import pytest
from text_to_sidc.austrian import UnitDesignator

@pytest.mark.parametrize("input_text, expected_sidc", [
    # ОВТ
    ("08.08.21 1 од. ОіВТ невизначеного типу (Космічний знімок)", "10061500001200000000"),
    # C2, КШМ
    ("02.08.23 неідентифікований КП ров, на північний захід від Червонопопівка (Взаємодія)", "10061000001100000000"), 
    ("Командно-спостережний пункт (КСП)", "10061000001100000000"),
    ("КШМ", "10061500001201020000"),
    # ППО Бук
    ("18.08.23 1 ЗРК 9К37 “Бук” (Космічний знімок)", "10061500331111040000"), 
    ("09.09.23 1 од. ПУ Бук-М2 біля н.п Нововасилівка (Взаємодія)", "10061500331111040000"),
    ("БУК М3", "10061500331111040000"),
    ("БУК", "10061500331111040000"),
    ("9А317", "10061500331111040000"),
    ("BUK M3", "10061500331111040000"),
    ("BUK M2", "10061500331111040000"),
    # Additional test cases
         # ППО С-300В
    ("20.08.23 Російський С-300ВМ «Антей-2500» (Взаємодія)", "10061500331111070000"),
    ("РЛС 9С15", "10061500332203000000"),
    # РЛС
    ("21.08.23 РЛС 91N6 (Взаємодія)", "10061500322203000000"),
    ("РЛС 76Н6", "10061500322203000000"),
    ("ЗРК БУК М3 СОЦ 9С18 КУПОЛ", "10061500332203000000"),
    ("21.08.23 РЛС 91N6 (Взаємодія)", "10061500322203000000"),
    ("04.09.23 Ніобій-СВ", "10061500322203000000"),
    ("РЛС 1Л122-1Е «Гармонь»", "10061500002203000000"),
    ("РЛС ППО 1Л122-1Е Гармонь", "10061500002203000000"),
    # Тестую регулярку
    # ("Я ищу в РЛСAвске ", None),
    # ІФО
    ("Траншея", "10062500002812000000"),
    ("Окоп", "10062500002812000000"),
    ("Виявлено ФОМ (космічний знімок)", "10062500002812000000"),
    # Пеленги радіостанцій космос
    ("VSAT", "10061000001110040000"),
    ("P-438", "10061000001110040000"),
    ("Р-441", "10061000001110040000"),
    ("Пеленг станції тропосферного зв'язку Р-423", "10061000001110040000"),
    ("MULTIPLE GROUND SATELLITES", "10061000001110040000"),
    # Пеленги радіостанцій
    ("Р-440", "10061500002001000000"),
    # Signal - Radio
    ("05.09.2023 Пеленг R-444 5386677 7424920", "10061000001110010000"),
    ("Р-444", "10061000001110010000"),
    ("Р-187", "10061000001110010000"),
    ("01.0923 Пеленг радіостанції Азарт R-187 61 Засічок  /10 днів, 47.4931, 35.6743", "10061000001110010000"),
    ("P-187", "10061000001110010000"),
    ("ПЕЛЕНГ РАДІОСТАНЦІЇ R-168", "10061000001110010000"),
    ("Р-168", "10061000001110010000"),
    ("Р-392", "10061000001110010000"),
    ("DMR", "10061000001110010000"),
    ("Пеленг УКХ зв'язку", "10061000001110010000"),
    ("P-392", "10061000001110010000"),
    ("АМ зв'язку", "10061000001110010000"),
    # Signal - Radio Relay
    ("Пеленг радіорелейної станції Р-419", "10061000001110020000"),
    ("Пеленг радіорелейної станції Р-415", "10061000001110020000"),
    ("Р-409", "10061000001110020000"),
    ("реле зв’язку св зс рф", "10061000001110020000"),
    # Signal
    ("10.09.23 АМ зв’язку (Взаємодія)", "10061000001110000000"),
    ("Пеленг невстановленого обладнання", "10061000001110000000"),
    ("AR-2", "10061000001110000000"),
    ("COMMS STATION", "10061000001110000000"),
    #
    ("22.08.23 Вогневе ураження", "10064000001106000000"),
    ("26.08.23 МТ-12 Рапіра", "10061500351106010000"),
    ("31.08.23 1 БАТ-2, 5 вантажних військових автомобілів (Космічний знімок)", "10061500001311000000"),
    ("01.09.23 'Стріла-2М' (9К32)", "10061500331111010000"),
    ("09.09.23 «Стріла-3» (9К34)", "10061500331111010000"),
    # ЗРК ТОР
    ("02.09.23 ЗРК ТОР рф (Взаємодія)", "10061500331111050000"),
    ("ТОР М2", "10061500331111050000"),
    ("TOP М1", "10061500331111050000"),
    ("ТОР М1", "10061500331111050000"),
    ("SAM TOR M2", "10061500331111050000"),
    ("SAM TOR M1/M2", "10061500331111050000"),
    ("SA-15", "10061500331111050000"),
    # Панцир
    ("31.08.23 ЗРК ПАНЦИРЬ-С2 (Взаємодія)", "10061500321111040000"),
    ("01.09.23 ЗРГК ПАНЦИР рф (Взаємодія)", "10061500321111040000"),
    ("02.09.23 ЗРГК ПАНЦИР-С2 (Взаємодія)", "10061500321111040000"),
    ("ЗРК ППО ПАНЦИР С1", "10061500321111040000"),
    ("ЗРК ППО ПАНЦИР С2", "10061500321111040000"),
    ("ЗРК ППО ОСА", "10061500321111050000"),
    ("ОСА", "10061500321111050000"),
    ("ЗРК Панцир-С2", "10061500321111040000"),
    # РЕБ
    ("04.09.23 Комплекс придушення сигналів навігаційних систем", "10061000001505040000"),
    ("04.09.23 Борисоглебськ-2", "10061000001505040000"),
    ("10.09- Пеленг P-934БМВ 50.2731 38.0172", "10061000001505040000"),
    ("04.09.23 96Л6", "10061500322203000000"),
    ("Р-934", "10061000001505040000"),
    ("Створення перешкод", "10061000001505040000"),
    ("EW", "10061000001505040000"),
    # мінування
    ("05.09.23 Район мінування", "10062500002707010000"),
    ("Міни ТМ-62", "10061500002103000000"),
    # птрк
    ("04.09.23 «Метис-М» (9К115-2)", "10061500001112030000"),
    ("17.09.23 позиція ПТРК 72 омсбр", "10061500001112000000"),
    ("Пускова установка протитанкової ракети", "10061500001117000000"),
    # паливо
    ("Топливозаправники 4 од.", "10061500321409000000"),
    ("Транспорт ПММ", "10061500321409000000"),
    ("30 ОС, 5 ВАТ, 7 бензовозів", "10061500321409000000"),
    # артилерія
    ("ствольна артилерія", "10061500001109000000"),
    ("Артилерія", "10061500001109000000"),
    ("Артилерійські установки", "10061500001109000000"),
    ("Орудие", "10061500351107000000"),
    ("ARTILLERY", "10061500001109000000"),
    # ОТРК
    ("Іскандер", "10061500321113000000"),
    # Піхота
    ("Піхота", "10061000001211000000"),
    ("INFANTRY", "10061000001211000000"),
    # міномет
    ("Міномет 120 мм (буксирований)", "10061500351114030000"),
    ("Артилерія на вогневих позиціях: ймовірно 1 міномет 2С4", "10061510331114030000"),
    ("MORTAR", "10061500001114000000"),
    # САУ
    (" Гвоздика", "10061500331109010000"),
    # Проживання
    ("Проживання ОС", "10062000001208000000"),
    # авіація
    ("Су-34 в польоті на південний захід", "10060100001101050000"),
    ("Ан-72", "10060100001101070000"),
    ("Ан-26", "10060100001101070000"),
    # Відео
    ("Відео (бойова камера)", "10061000001112000000"),
    # гранатомет
    ("Гранатомет", "10061500001103000000"),
    # ремонт і обслуговування
    ("Ремонтна база", "10062000001213060000"),
    ("База ремонту / відновлення", "10062000001213060000"),
    # медичка
    ("Стабілізаційний медичний пункт", "10062000001207020000"),
    # навчальний табір
    ("Навчальний табір", "10062000001119020000"),
    ("Навчальний полігон ров", "10062000001119020000"),
    # автомобілі / ЛАТ
    ("Автомобіль", "10061500001601000000"),
    # кулемет
    ("Кулемет", "10061500001102000000"),
    # вогневі позиції
    ("арт. позиція", "10062500002501000000"),
    ("вогневі позиції", "10062500002501000000"),
    # залізниця
    ("Залізнична станція РОДАКОВО", "10062000001213070000"),
    ("Залізничні станції Дебальцеве та Дебальцеве-Сортувальна", "10062000001213070000"),
    ("Локомотивне депо Дебальцеве", "10062000001213070000"),
    # місце перезаряджання
    ("Місце перезарядження  артилерії", "10062500003202000000"),
    # підрозділ
    ("тактичний підрозділ св зс рф", "10061000001200000000"),
    # евак
    ("Група евакуації", "10062500003211000000"),
    # КББ
    ("РЛК ЯСТРЕБ АВ", "10061500322203000000"),
    # СП
    ("Створення: 2024-01-10 13:52:40 | pep Оновлення: 2024-01-10 13:52:36 | pep Lat, Lng: 48.196246, 37.678888 DMS: N48°11'46.49', E37°40'44.00' СК-42: X: 5341194, Y: 7401900 MGRS: 37UDP0182638956 UTM: Z: 37U, E: 401826, N: 5338956 Тип: Спостережний пункт (СП) - Аванпост передового спостерігача - Точка/аванпост спостереження - Точки маневрування - Польові укріплення та умовні точки Ворожість: Ворожий Висота над рівнем моря, м: 204 UUID: 1f3d3d9e-24d8-4745-9932-694c241dc686", "10062500001601000000"),
    # точки
    ("Пункт загального постачання", "10062500003217000000"),
    ("TROOP SUSTAINMENT/MILITARY TRUCKS", "10062500003217000000"),
    ("TROOP SUSTAINMENT / CARGO", "10062500003217000000"),
    ("WEAPONS / EQUIPTMENT SHIPMENT", "10062500003217000000"),
    # склади
    ("склади боєприпасів", "10062000001103000000"),
    ("AMMUNITION CACHE", "10062000001103000000"),
    # БПЛА
    ("GCS", "10061000111219000021"),
    # інфраструктура
    ("Міст автомобільний, р. Красна, північ Сватове. з квітня 2023", "10062000001107010000"),
    ("BRIDGE CONSTRUCTION", "10062000001107010000"),
    ("FLOATING BRIDGE", "10061500001304000000"),
    ("Електропідстанція Михайлівська-400 ПС 400/330/220/110 кВ. від ЛБЗ 30 км", "10062000001205010000"),
    ("Електрична підстанція", "10062000001205010000"),
    ("WATER SUPPLY INFRASTRUCTURE", "10062000001214000000"),
    ("PETROL STATION", "10062000001205040000"),
    ("ENERGY FACILITY", "10062000001205000000"),
    # госпіталь/лікарня
    ("3RD MSD MEDICAL FACILITY", "10062000001207020000"),
    # вантажівка
    ("MILITARY CARGO VEHICLES", "10061500001408000000"),
    # антена
    ("BROADCAST ANTENNA", "10061500002001000000"),
    # міни
    ("Конец мон50 9шт, пмн4-20 шт, пмн2-70 шт", "10061500002102000000"),

    # c2
    ("c2 ", "10061000001100000000"),
    (" c2 ", "10061000001100000000"),
    ("c211", "10012500001313000000"),
    ("c2", "10061000001100000000"),
    ("c2", "10061000001100000000"),
    ("4с25-4g4g", "10012500001313000000"),
    ("4с2-4g4g", "10012500001313000000"),

    # КСП
    ("СПОСТЕРЕЖНИЙ ПУНКТ", "10062500001601000000"),
    ("КОМАНДНО-СПОСТЕРЕЖНИЙ ПУНКТ", "10061000001100000000"),

    # Підрозділи
    ("1008 ТрВ", "10061000001211000000"),
    ("7 орб 47 тд", "10061000161205010000"),
    ("1472 мсп 68 ак\39 омсбр (?)","10061000171211020000"),
    ("2614 сб МР","10061000151211040000"),
    ("БАРС-8","10061000001211000000"),
    # ("113 сп\116 осп  МР 1 АК","10062500001601000000"), видає таке, бо смика механ роту'10061000151211040000 МСР|МР'
    ("242 мсп 20 мсд 8 зва","10061000171211020000"),
    ("104 дшп 76 дшд","10061000171201000000"),
    ("22 обрспп","10061000001217000000"),
    ("4 осб ТрО","10061000161211000000"),
    ("1857 мсб ТрВ","10061000161211040000"),
    # ('119 сп МР\87 осп ""Пятнашка"" (?) 1 АК',"10062500001601000000"), смикає СП до підрозд
    ('7 ДРШБр ""Святой Георгій"""',"10061000001211000100"),
    ("272 мсп 47 тд 1 та","10061000171211020000"),
    ("1660 омсб 20 зва","10061000161211040000"),
    ("337 дшп 104 дшд ПДВ","10061000141201000000"),
    ("60 омсбр 5 зва","10061000181211040000"),
    ("3 мсб 347 мсп 47 тд 1 ТА","10061000161211040000"),
    ("БАРС-19","10061000001211000000"),
    ("ксб Єгорлик","10061000001211000000"),
    ("нв Ахмат","10061000001211001400"),
    ("БАРС-2 47 тд 1 та","10061000001211000000"),
    ("1618 омсб ТрВ","10061000161211040000"),
    ("БАРС-20","10061000001211000000"),
    ("79 орб 2 ак","10061000161213000000"),
    ("136 орб 2 мсд 1 ТА","10061000161205010000"),
    ("оз СпП 2 обрсппн","10061000001217000000"),
    ("1009 мсп (без 1 і 3 мсб) 25 омсбр 6 зва","10061000161211040000"),
    ("шр 5 мсб (з тр) 1 мсп 2 мсд","10061000161211040000"),
    ("26 сб 36 омсбр 29 зва","10061000161211000000"),
    ("85 омсбр 2 ак 8 зва","10061000181211040000"),
    ("1 дршбр “Волкі”","10061000001211000100"),
    ("11 отбр 25 зва","10061000001211000000"),
    ("підрозділи 388-ї бригади морського спецназу","10061000001217000000"),
    ("794 оз СпП 14 обрсппн","10061000001217000000"),
    ("2 обСпП ОБТФ","10061000001217000000"),
    ("1440 мсп ТрВ","10061000171211020000"),
    ("907 орб 27 мсд 2 зва","10061000161205010000"),
    ("137 пдп 106 пдд","10061000171201000000"),
    ("297 осб 2 ак","10061000161211000000"),
    ("382 обмп 810 обрмп","10061000001203000000"),
    ("12 мсб 6 оп РХБз 6 зва","10061000161211040000"),
    ("102 мсп 150 мсд","10061000171211020000"),
    ("1441 мсп ТрВ 30 омсбр 2 зва","10061000171211020000"),
    ("143 мсп 127 мсд 5 зва","10061000171211020000"),
    ("9 омсп9 омсбр 1 АК","10061000171211020000"),
    ("1436 мсп ТрВ 114 омсбр 1 ак 8 зва","10061000171211020000"),
    ("1 мсб 1009 мсп 25 омсбр 6 зва","10061000161211040000"),
    ("17 мсб з тр 488 мсп 144 мсд 20 зва","10061000161211040000"),
    ("1152 мсп ТрВ 47 мсд 18 зва","10061000171211020000"),
    ("102 ообпдс","10061000001211000000"),
    ("15 зсб 252 мсп 3 мсд 20 зва","10061000171211020000"),
    ("фпв", "10060100001103000100"),
    ("РСЗО", "10061500321116000000"),
    ("СПГ", "10061500001103030000")

])

def test_unit_designator(input_text: str, expected_sidc: str) -> None:
    sidc = UnitDesignator.calculate_icon(input_text.upper())
    assert sidc == expected_sidc, f"Expected SIDC: {expected_sidc}, but got: {sidc} with input: {input_text}"
